==> org.eclipse.scout.sdk.ui.source_4.0.0.20140505-1008.jar: org/eclipse/scout/sdk/ui/wizard/form/handler/FormHandlerNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.wizard.form.handler;

import org.eclipse.jdt.core.IType;
import org.eclipse.scout.sdk.Texts;
import org.eclipse.scout.sdk.ui.extensions.AbstractFormFieldWizard;
import org.eclipse.scout.sdk.ui.internal.ScoutSdkUi;
import org.eclipse.scout.sdk.util.type.TypeUtility;

public class FormHandlerNewWizard extends AbstractFormFieldWizard {

  private FormHandlerNewWizardPage1 m_page1;
  private FormHandlerNewWizardPage2 m_page2;

  public FormHandlerNewWizard(IType formType) {
    setWindowTitle(Texts.get("NewFormHandler"));
    initWizard(formType);
  }

  @Override
  public void initWizard(IType declaringType) {
    super.initWizard(declaringType);
    m_page1 = new FormHandlerNewWizardPage1(getDeclaringType());
    addPage(m_page1);
    m_page2 = new FormHandlerNewWizardPage2(getDeclaringType());
    addPage(m_page2);
  }

  @Override
  public void setSuperType(IType superType) {
    m_page1.setSuperType(superType);
  }

  @Override
  protected void postFinishDisplayThread() {
    IType createdField = m_page2.getCreatedFormHandler();
    if (TypeUtility.exists(createdField)) {
      ScoutSdkUi.showJavaElementInEditor(createdField, false);
    }
  }
}

==> org.eclipse.scout.sdk.ui.source_5.0.0.20150608-0810.jar: org/eclipse/scout/sdk/ui/wizard/form/handler/FormHandlerNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.wizard.form.handler;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.scout.sdk.Texts;
import org.eclipse.scout.sdk.ui.extensions.AbstractInnerTypeWizard;
import org.eclipse.scout.sdk.ui.internal.ScoutSdkUi;
import org.eclipse.ui.IWorkbench;

public class FormHandlerNewWizard extends AbstractInnerTypeWizard {

  private FormHandlerNewWizardPage1 m_page1;
  private FormHandlerNewWizardPage2 m_page2;

  @Override
  public void init(IWorkbench workbench, IStructuredSelection selection) {
    super.init(workbench, selection);

    setWindowTitle(Texts.get("NewFormHandler"));

    m_page1 = new FormHandlerNewWizardPage1(getDeclaringType());
    if (getSuperType() != null) {
      m_page1.setSuperType(getSuperType());
    }
    addPage(m_page1);
    m_page2 = new FormHandlerNewWizardPage2(getDeclaringType());
    if (getTypeName() != null) {
      m_page2.setTypeName(getTypeName());
    }
    addPage(m_page2);
  }

  @Override
  protected void postFinishDisplayThread() {
    ScoutSdkUi.showJavaElementInEditor(m_page2.getCreatedFormHandler(), false);
  }
}
